@@ -22,9 +22,9 @@ REDIS_CONNECTION = connect_to_redis()
 QUIZ_CONTENT = get_quiz_content_from_redis(REDIS_CONNECTION)
 
 BUTTON_NEW_QUESTION = 'Новый вопрос'
-BUTTON_SURRENDER = 'Сдаться'
+BUTTON_GIVE_IN = 'Сдаться'
 BUTTON_SCORE = 'Мой счет'
-QUESTION_IS_SET_INCORRECTLY_BUTTON = 'Вопрос составлен неверно'
+BUTTON_QUESTION_IS_MADE_INCORRECTLY = 'Вопрос составлен неверно'
 
 CHOOSING, WAIT_ANSWER = range(2)
 
@@ -47,14 +47,14 @@ def handle_new_question_request(update, context) -> int:
     """Sends a random question to the user."""
     question, number_of_question = get_random_question(QUIZ_CONTENT)
 
-    if context.user_data.get('was_the_surrender_button_pressed'):
+    if context.user_data.get('button_give_in_flag'):
         custom_keyboard = [
-            [BUTTON_SURRENDER, BUTTON_SCORE],
-            [QUESTION_IS_SET_INCORRECTLY_BUTTON],
+            [BUTTON_GIVE_IN, BUTTON_SCORE],
+            [BUTTON_QUESTION_IS_MADE_INCORRECTLY],
         ]
     else:
         custom_keyboard = [
-            [BUTTON_SURRENDER, BUTTON_SCORE],
+            [BUTTON_GIVE_IN, BUTTON_SCORE],
         ]
     send_message_to_tg_chat(
         update,
@@ -84,12 +84,12 @@ def handle_solution_attempt(update, context):
         last_asked_question=last_asked_question,
     )
     clean_answer = get_clean_text_of_answer(answer_to_last_question_of_user)
-    if update.message.text.lower() == clean_answer:
+    if update.message.text == clean_answer:
         message_text = 'Правильно! Для следующего вопроса нажми «Новый вопрос»'
         custom_keyboard = [[BUTTON_NEW_QUESTION]]
     else:
         message_text = 'Неправильно... Попробуешь ещё раз?'
-        custom_keyboard = [[BUTTON_SURRENDER, BUTTON_SCORE]]
+        custom_keyboard = [[BUTTON_GIVE_IN, BUTTON_SCORE]]
 
     send_message_to_tg_chat(
         update,
@@ -100,8 +100,8 @@ def handle_solution_attempt(update, context):
     return CHOOSING
 
 
-def handle_opportunity_to_surrender(update, context):
-    """Handles clicking the "Surrender" button.
+def handle_opportunity_to_give_in(update, context):
+    """Handles clicking the "Give in" button.
 
     The bot sends the user an answer to the question
     and sends the next question with the next message.
@@ -119,7 +119,7 @@ def handle_opportunity_to_surrender(update, context):
         update,
         answer_to_last_question_of_user,
     )
-    context.user_data['was_the_surrender_button_pressed'] = True
+    context.user_data['button_give_in_flag'] = True
 
     handle_new_question_request(update, context)
 
@@ -128,7 +128,7 @@ def handle_opportunity_to_surrender(update, context):
 
 def handler_question_is_incorrect(update, context):  # noqa: WPS226
     """Handles clicking the button 'The question is incorrect'."""
-    custom_keyboard = [[BUTTON_SURRENDER, BUTTON_SCORE]]
+    custom_keyboard = [[BUTTON_GIVE_IN, BUTTON_SCORE]]
     send_message_to_tg_chat(
         update,
         'Спасибо за фидбек! Ждем ответ на предыдущий вопрос!',
@@ -167,13 +167,13 @@ def start_tg_bot():
                 ),
                 MessageHandler(
                     Filters.regex('^Сдаться$'),
-                    handle_opportunity_to_surrender,
+                    handle_opportunity_to_give_in,
                 ),
             ],
             WAIT_ANSWER: [
                 MessageHandler(
                     Filters.regex('^Сдаться$'),
-                    handle_opportunity_to_surrender,
+                    handle_opportunity_to_give_in,
                 ),
                 MessageHandler(
                     Filters.regex('^Вопрос составлен неверно$'),
